# -*- coding: utf-8 -*-
"""
Module implementing SettingsDialog.
"""
from PyQt4.QtGui import QDialog, QFileDialog
from PyQt4.QtCore import pyqtSignature,  QLocale,  QDir,  QStringList

from .Ui_settings import Ui_SettingsDialog

class SettingsDialog(QDialog, Ui_SettingsDialog):
    def __init__(self, parent = None):
        QDialog.__init__(self, parent)
        self.setupUi(self)
            
    def loadSettings(self, settings):
        self.settings = settings
        currentLocale = self.settings.value('Localization/locale')
        dir = QDir("translations/")
        fileNames = dir.entryList(QStringList("qmingus_*.qm"))
        for i in range(0,  fileNames.count()):
            locale = fileNames[i]
            locale.truncate(locale.lastIndexOf('.'))
            locale.remove(0, locale.indexOf('_') + 1)
            lang = QLocale.languageToString(QLocale(locale).language())
            
            self.langComboBox.addItem(lang, locale)
            if (locale == currentLocale):
                self.langComboBox.setCurrentIndex(self.langComboBox.count() - 1)
        
        sfPath =  self.settings.value('Midi/soundfont')
        self.sfLineEdit.setText(sfPath.toString())
    
        audioDriver = self.settings.value('Midi/driver')
        for i in range(0,  self.adComboBox.count()):
            if (audioDriver == self.adComboBox.itemText(i)):
                self.adComboBox.setCurrentIndex(i)
        
 
    @pyqtSignature("int")
    def on_langComboBox_currentIndexChanged(self,  pos):
        idx = self.langComboBox.currentIndex()
        locale  = self.langComboBox.itemData(idx).toString()
        #QLocale.setDefault(QLocale(locale))

    @pyqtSignature("")
    def on_sfButton_clicked(self):
        fileName = QFileDialog.getOpenFileName()
        if fileName.count() > 0:
            self.sfLineEdit.setText(fileName)
    
    @pyqtSignature("")
    def on_okButton_clicked(self):
        self.applySettings()
        self.close()
        
    @pyqtSignature("")
    def on_applyButton_clicked(self):
        self.applySettings()
        
    @pyqtSignature("")
    def on_cancelButton_clicked(self):
        self.close() 
        
    @pyqtSignature("")
    def applySettings(self):
        self.settings.setValue('Localization/locale', self.langComboBox.itemData(self.langComboBox.currentIndex()))
        self.settings.setValue('Midi/soundfont', self.sfLineEdit.text())
        self.settings.setValue('Midi/driver', self.adComboBox.currentText())
        
